@@ -29,7 +29,15 @@ class TestGeometryRegistration:
 
         original = Dataset()
         original["dy"] = DataArray(np.ones((3, 4)), dims=("x", "y"))
-        original.attrs["metadata"] = {}
+        metadata = {
+            "bout_xdim": "x",
+            "bout_ydim": "y",
+            "bout_zdim": "z",
+            "keep_xboundaries": True,
+            "keep_yboundaries": True,
+        }
+        original.attrs["metadata"] = metadata
+        original["dy"].attrs["metadata"] = metadata
         updated = apply_geometry(ds=original, geometry_name="Schwarzschild")
         assert_equal(updated["event_horizon"], DataArray(4.0))
 
