@@ -54,12 +54,6 @@ class TestRegion:
 
         n = ds["n"]
 
-        if guards["y"] > 0 and not keep_yboundaries:
-            # expect exception for core topology due to not having neighbour cells to get
-            # coordinate values from
-            with pytest.raises(ValueError):
-                n_core = n.bout.from_region("core")
-            return
         n_core = n.bout.from_region("core")
 
         # Remove attributes that are expected to be different
@@ -73,7 +67,9 @@ class TestRegion:
             ybndry = 0
         xrt.assert_identical(
             n.isel(theta=slice(ybndry, -ybndry if ybndry != 0 else None)),
-            n_core.isel(theta=slice(ybndry, -ybndry if ybndry != 0 else None)),
+            n_core.isel(
+                theta=slice(guards["y"], -guards["y"] if guards["y"] != 0 else None)
+            ),
         )
 
     @pytest.mark.long
@@ -114,14 +110,14 @@ class TestRegion:
 
     @pytest.mark.parametrize(params_guards, params_guards_values)
     @pytest.mark.parametrize(params_boundaries, params_boundaries_values)
-    @pytest.mark.parametrize("test_dataset", [False, True])
+    @pytest.mark.parametrize("region_guards", [0, 1])
     def test_region_limiter(
         self,
         bout_xyt_example_files,
         guards,
         keep_xboundaries,
         keep_yboundaries,
-        test_dataset,
+        region_guards,
     ):
         # Note using more than MXG x-direction points and MYG y-direction points per
         # output file ensures tests for whether boundary cells are present do not fail
@@ -164,51 +160,40 @@ class TestRegion:
         # Remove attributes that are expected to be different
         del n_noregions.attrs["regions"]
 
-        if test_dataset:
-            ds_sol = ds.bout.from_region("SOL")
-            n_sol = ds_sol["n"]
-        else:
-            n_sol = n.bout.from_region("SOL")
+        n_sol = n.bout.from_region("SOL", with_guards=region_guards)
 
         # Remove attributes that are expected to be different
         # Corners may be different because core region 'communicates' in y
         del n_sol.attrs["regions"]
         xrt.assert_identical(
-            n_noregions.isel(x=slice(ixs, None)), n_sol.isel(x=slice(mxg, None))
+            n_noregions.isel(x=slice(ixs, None)),
+            n_sol.isel(x=slice(region_guards, None)),
         )
         xrt.assert_identical(
             n_noregions.isel(
-                x=slice(ixs - mxg, ixs),
+                x=slice(ixs - region_guards, ixs),
                 theta=slice(ybndry, -ybndry if ybndry != 0 else None),
             ),
             n_sol.isel(
-                x=slice(mxg), theta=slice(ybndry, -ybndry if ybndry != 0 else None)
+                x=slice(region_guards),
+                theta=slice(ybndry, -ybndry if ybndry != 0 else None),
             ),
         )
 
-        if guards["y"] > 0 and not keep_yboundaries:
-            # expect exception for core region due to not having neighbour cells to get
-            # coordinate values from
-            with pytest.raises(ValueError):
-                if test_dataset:
-                    ds_core = ds.bout.from_region("core")
-                else:
-                    n_core = n.bout.from_region("core")
-            return
-        if test_dataset:
-            ds_core = ds.bout.from_region("core")
-            n_core = ds_core["n"]
-        else:
-            n_core = n.bout.from_region("core")
+        n_core = n.bout.from_region("core", with_guards=region_guards)
 
         # Remove attributes that are expected to be different
         del n_core.attrs["regions"]
         xrt.assert_identical(
             n_noregions.isel(
-                x=slice(ixs + mxg),
+                x=slice(ixs + region_guards),
                 theta=slice(ybndry, -ybndry if ybndry != 0 else None),
             ),
-            n_core.isel(theta=slice(ybndry, -ybndry if ybndry != 0 else None)),
+            n_core.isel(
+                theta=slice(
+                    region_guards, -region_guards if region_guards != 0 else None
+                )
+            ),
         )
 
     @pytest.mark.long
